# 安全政策

## 支援版本

| 版本 | 支援狀態 |
| ------- | ------------------ |
| 0.x.x   | :white_check_mark: |

## 回報漏洞

如果你發現安全漏洞，請**不要**公開在 Issues 中回報。

### 回報方式

1. 發送郵件至：[security@example.com]
2. 或使用 GitHub 的私人漏洞回報功能

### 回報內容

請包含以下資訊：

- 漏洞描述
- 重現步驟
- 可能的影響範圍
- 建議的修復方式（如果有）

### 回應時程

- 48 小時內確認收到回報
- 7 天內初步評估
- 90 天內修復（視嚴重程度調整）

### 感謝

我們感謝所有負責任地回報安全問題的研究人員。
